==> flutter_math-0.1.3.tar.gz: lib/src/parser/tex/functions/katex_base/rule.dart <==
// The MIT License (MIT)
//
// Copyright (c) 2013-2019 Khan Academy and other contributors
// Copyright (c) 2020 znjameswu <znjameswu@gmail.com>
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

part of katex_base;

const _ruleEntries = {
  ['\\rule']:
      FunctionSpec(numArgs: 2, numOptionalArgs: 1, handler: _ruleHandler),
};
GreenNode _ruleHandler(TexParser parser, FunctionContext context) {
  final shift = parser.parseArgSize(optional: true) ?? Measurement.zero;
  final width = parser.parseArgSize(optional: false) ?? Measurement.zero;
  final height = parser.parseArgSize(optional: false) ?? Measurement.zero;

  return SpaceNode(
    height: height,
    width: width,
    shift: shift,
    background: Colors.black,
    mode: Mode.math,
  );
}

==> flutter_math-0.2.1.tar.gz: lib/src/parser/tex/functions/katex_base/rule.dart <==
// The MIT License (MIT)
//
// Copyright (c) 2013-2019 Khan Academy and other contributors
// Copyright (c) 2020 znjameswu <znjameswu@gmail.com>
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.

part of katex_base;

const _ruleEntries = {
  ['\\rule']:
      FunctionSpec(numArgs: 2, numOptionalArgs: 1, handler: _ruleHandler),
};
GreenNode _ruleHandler(TexParser parser, FunctionContext context) {
  final shift = parser.parseArgSize(optional: true) ?? Measurement.zero;
  final width = parser.parseArgSize(optional: false) ?? Measurement.zero;
  final height = parser.parseArgSize(optional: false) ?? Measurement.zero;

  return SpaceNode(
    height: height,
    width: width,
    shift: shift,
    fill: true,
    // background: Colors.black,
    mode: Mode.math,
  );
}
